/*
*******************************************************************************
**
**  This device driver was created by Applilet2 for 78K0/Kx2
**  8-Bit Single-Chip Microcontrollers
**
**  Copyright(C) NEC Electronics Corporation 2002 - 2011
**  All rights reserved by NEC Electronics Corporation.
**
**  This program should be used on your own responsibility.
**  NEC Electronics Corporation assumes no responsibility for any losses
**  incurred by customers or third parties arising from the use of this file.
**
**  Filename :	Int.h
**  Abstract :	This file implements device driver for INT module.
**  APIlib :	Applilet2 for 78K0/Kx2 V2.41 [29 Apr. 2008]
**
**  Device :	uPD78F0512_48
**
**  Compiler :	CC78K0
**
**  Creation date:	2011/03/27
**  
*******************************************************************************
*/
#ifndef _MDINT_
#define _MDINT_
/*
*******************************************************************************
**	Register bit define
*******************************************************************************
*/
/*
 External Interrupt Rising Edge Enable Register (EGP)
*/
/* INTPn pin valid edge selection(EGP.EGPn) */
#define INTP_EGP_RESET_VALUE		0x00	/* external interrupt rising edge enable register value after reset */
#define INTP0_EDGE_RISING_SEL		0x01	/* rising edge selected for INTP0 pin */
#define INTP0_EDGE_RISING_UNSEL		0x00	/* rising edge not selected for INTP0 pin */
#define INTP1_EDGE_RISING_SEL		0x02	/* rising edge selected for INTP1 pin */
#define INTP1_EDGE_RISING_UNSEL		0x00	/* rising edge not selected for INTP1 pin*/
#define INTP2_EDGE_RISING_SEL		0x04	/* rising edge selected for INTP2 pin */
#define INTP2_EDGE_RISING_UNSEL		0x00	/* rising edge not selected for INTP2 pin */
#define INTP3_EDGE_RISING_SEL		0x08	/* rising edge selected for INTP3 pin */
#define INTP3_EDGE_RISING_UNSEL		0x00	/* rising edge not selected for INTP3 pin */
#define INTP4_EDGE_RISING_SEL		0x10	/* rising edge selected for INTP4 pin */
#define INTP4_EDGE_RISING_UNSEL		0x00	/* rising edge not selected for INTP4 pin */
#define INTP5_EDGE_RISING_SEL		0x20	/* rising edge selected for INTP5 pin */
#define INTP5_EDGE_RISING_UNSEL		0x00	/* rising edge not selected for INTP5 pin */
#define INTP6_EDGE_RISING_SEL		0x40	/* rising edge selected for INTP6 pin */
#define INTP6_EDGE_RISING_UNSEL		0x00	/* rising edge not selected for INTP6 pin */

/*
 External Interrupt Falling Edge Enable Register (EGN)
*/
/* INTPn pin valid edge selection(EGN.EGNn) */
#define INTP_EGN_RESET_VALUE		0x00	/* external interrupt falling edge enable register value after reset */
#define INTP0_EDGE_FALLING_SEL		0x01	/* falling edge selected for INTP0 pin */
#define INTP0_EDGE_FALLING_UNSEL	0x00	/* falling edge not selected for INTP0 pin */
#define INTP1_EDGE_FALLING_SEL		0x02	/* falling edge selected for INTP1 pin */
#define INTP1_EDGE_FALLING_UNSEL	0x00	/* falling edge not selected for INTP1 pin */
#define INTP2_EDGE_FALLING_SEL		0x04	/* falling edge selected for INTP2 pin */
#define INTP2_EDGE_FALLING_UNSEL	0x00	/* falling edge not selected for INTP2 pin */
#define INTP3_EDGE_FALLING_SEL		0x08	/* falling edge selected for INTP3 pin */
#define INTP3_EDGE_FALLING_UNSEL	0x00	/* falling edge not selected for INTP3 pin */
#define INTP4_EDGE_FALLING_SEL		0x10	/* falling edge selected for INTP4 pin */
#define INTP4_EDGE_FALLING_UNSEL	0x00	/* falling edge not selected for INTP4 pin */
#define INTP5_EDGE_FALLING_SEL		0x20	/* falling edge selected for INTP5 pin */
#define INTP5_EDGE_FALLING_UNSEL	0x00	/* falling edge not selected for INTP5 pin */
#define INTP6_EDGE_FALLING_SEL		0x40	/* falling edge selected for INTP6 pin */
#define INTP6_EDGE_FALLING_UNSEL	0x00	/* falling edge not selected for INTP6 pin */
/* Key interrupt mode control(KRM.KRMn)*/
#define KR_KRM_RESET_VALUE			0x00	/* KRM value after reset */
#define KR0_SIGNAL_DETECT_ON		0x01	/* Detects KR0 signal */
#define KR0_SIGNAL_DETECT_OFF		0x00	/* Does not detect KR0 signal */
#define KR1_SIGNAL_DETECT_ON		0x02	/* Detects KR1 signal */        
#define KR1_SIGNAL_DETECT_OFF		0x00	/* Does not detect KR1 signal */
#define KR2_SIGNAL_DETECT_ON		0x04	/* Detects KR2 signal */        
#define KR2_SIGNAL_DETECT_OFF		0x00	/* Does not detect KR2 signal */
#define KR3_SIGNAL_DETECT_ON		0x08	/* Detects KR3 signal */        
#define KR3_SIGNAL_DETECT_OFF		0x00	/* Does not detect KR3 signal */

/*
*******************************************************************************
**  Macro define
*******************************************************************************
*/
enum MaskableSource {
	INT_LVI, INT_INTP0, INT_INTP1, INT_INTP2,
	INT_INTP3, INT_INTP4, INT_INTP5, INT_SRE6,
	INT_SR6, INT_ST6, INT_CSI10_ST0, INT_TMH1,
	INT_TMH0, INT_TM50, INT_TM000, INT_TM010,
	INT_AD, INT_SR0, INT_WTI, INT_TM51,
	INT_KR, INT_WT, INT_INTP6,
	INT_IIC0 = 24
	};

/*
*******************************************************************************
**  Function define
*******************************************************************************
*/
void INTP_Init( void );
__interrupt void MD_INTP1( void );
/* Start user code for definition. Do not edit comment generated here */
/* End user code for definition. Do not edit comment generated here */
#endif
